==> ae2wtlib-19.2.1.jar: assets/ae2wtlib/ae2guide/ae2wtlib/wireless_crafting_terminal.md <==
---
navigation:
  parent: ae2wtlib/ae2wtlib-index.md
  title: Wireless Crafting Terminal
  icon: ae2:wireless_crafting_terminal
  position: 100
categories:
- ae2wtlib
item_ids:
  - ae2:wireless_crafting_terminal
---

# Wireless Crafting Terminal

<ItemImage id="ae2:wireless_crafting_terminal" scale="3" />

The <ItemLink id="ae2:wireless_crafting_terminal" /> is a [wireless](wireless_terminals.md) version of the <ItemLink id="ae2:crafting_terminal" />.
AE2WTLib adds automatic [restocking](restock.md) from the ME Network, and allows Pick Block to draw items from the ME Network.   
With a <ItemLink id="ae2wtlib:magnet_card" /> it also acts as a magnet.

It can be combined with other [Wireless Terminals](wireless_terminals.md) into an <ItemLink id="ae2wtlib:wireless_universal_terminal" />

AE2WTLib enhances Minecrafts `Pick Block` functionality, it will draw items from the network if they can't be found in your inventory.
(It will also try to store items if your current slot happens to be full)

## The UI

See [Terminals](ae2:items-blocks-machines/terminals.md)

## Upgrades

The Wireless Crafting Terminal supports the following [upgrades](ae2:items-blocks-machines/upgrade_cards.md):

*   <ItemLink id="ae2:energy_card" /> in order to increase the battery capacity
*   <ItemLink id="ae2wtlib:quantum_bridge_card" /> which allows the terminal to have unlimited range, even across dimensions and automatically charges the terminal from the ME Network 
*   <ItemLink id="ae2wtlib:magnet_card" /> to add magnet functionality

## Recipe

<RecipeFor id="ae2:wireless_crafting_terminal" />

==> ae2wtlib-19.2.2.jar: assets/ae2wtlib/ae2guide/ae2wtlib/wireless_crafting_terminal.md <==
---
navigation:
  parent: ae2wtlib/ae2wtlib-index.md
  title: Wireless Crafting Terminal
  icon: ae2:wireless_crafting_terminal
  position: 100
categories:
- ae2wtlib
item_ids:
  - ae2:wireless_crafting_terminal
---

# Wireless Crafting Terminal

<ItemImage id="ae2:wireless_crafting_terminal" scale="3" />

The <ItemLink id="ae2:wireless_crafting_terminal" /> is a [wireless](wireless_terminals.md) version of the <ItemLink id="ae2:crafting_terminal" />.
AE2WTLib adds automatic [restocking](restock.md) from the ME Network, and allows Pick Block to draw items from the ME Network.   
With a <ItemLink id="ae2wtlib:magnet_card" /> it also acts as a magnet.

It can be combined with other [Wireless Terminals](wireless_terminals.md) into an <ItemLink id="ae2wtlib:wireless_universal_terminal" />

AE2WTLib enhances Minecrafts `Pick Block` functionality, it will draw items from the network if they can't be found in your inventory.
(It will also try to store items if your current slot happens to be full)

## The UI

See [Terminals](ae2:items-blocks-machines/terminals.md)

## Upgrades

The <ItemLink id="ae2:wireless_crafting_terminal" /> supports the following [upgrades](ae2:items-blocks-machines/upgrade_cards.md):

*   <ItemLink id="ae2:energy_card" /> in order to increase the battery capacity
*   <ItemLink id="ae2wtlib:quantum_bridge_card" /> which allows the terminal to have unlimited range, even across dimensions and automatically charges the terminal from the ME Network 
*   <ItemLink id="ae2wtlib:magnet_card" /> to add magnet functionality

## Recipe

<RecipeFor id="ae2:wireless_crafting_terminal" />
